@@ -249,7 +249,7 @@ feedHandlerPtr feed_parse(feedPtr fp, gchar *data, size_t dataLength, gboolean a
  * (2) Inside of feed_process_result
  * (3) The callback where items are removed from the itemlist
  *
- * This method really save the feed to disk.
+ * This method really saves the feed to disk.
  */
 void feed_save(feedPtr fp) {
 	xmlDocPtr 	doc;
@@ -707,7 +707,7 @@ void feed_add_item(feedPtr fp, itemPtr new_ip) {
 			feed_increase_unread_counter(fp);
 		fp->items = g_slist_append(fp->items, (gpointer)new_ip);
 		new_ip->fp = fp;
-		/* item number should already be set by item_copy() */
+		new_ip->nr = ++(fp->lastItemNr);
 	}
 }
 
@@ -954,15 +954,28 @@ void feed_clear_item_list(feedPtr fp) {
 }
 
 /**
- * Method to permanently remove a single item from the given feed 
+ * Method to permanently remove a single item from the given feed.
+ * Used to remove items from everything that has items... 
  */
 void feed_remove_item(feedPtr fp, itemPtr ip) {
 
-	fp->items = g_slist_remove(fp->items, ip);	
-	if(FST_FEED == fp->type)
-		vfolder_remove_item(ip);		/* remove item copies */
-	item_free(ip);					/* remove the item */
-	fp->needsCacheSave = TRUE;
+	if(NULL == fp)
+		return;
+		
+	/*g_print("removing item %d from feed %d\n", ip, fp);
+	g_print("   feed:%s\n", fp->title);
+	g_print("   item:%s\n", ip->title);*/
+	if(NULL != g_slist_find(fp->items, ip)) {
+		fp->items = g_slist_remove(fp->items, ip);	
+		if(FST_FEED == fp->type) {
+			vfolder_remove_item(ip);		/* remove item copies */
+			fp->needsCacheSave = TRUE;
+		}
+		/*g_print("freeing item structure %d\n", ip);*/
+		item_free(ip);					/* remove the item */
+	} else {
+		g_warning("feed_remove_item(): item (%s) to be removed not found...", ip->title);
+	}
 }
 
 /** 
@@ -1141,15 +1154,18 @@ void feed_free(feedPtr fp) {
 		g_free(fp->id);
 	}
 	
-	g_free(fp->title);
-	g_free(fp->description);
+	g_free(fp->parseErrors);
 	g_free(fp->errorDescription);
-	g_free(fp->source);
-	g_free(fp->filtercmd);
+	g_free(fp->title);
 	g_free(fp->htmlUrl);
 	g_free(fp->imageUrl);
-	g_free(fp->parseErrors);
+	g_free(fp->description);
+	g_free(fp->source);
+	g_free(fp->filtercmd);
+	g_free(fp->lastModified);
+	g_free(fp->etag);
 	g_free(fp->cookies);
+	
 	metadata_list_free(fp->metadata);
 	g_hash_table_destroy(fp->tmpdata);
 	g_free(fp);
