@@ -74,22 +74,20 @@ GtkTreeStore * ui_itemlist_get_tree_store(void) {
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(lookup_widget(mainwindow, "Itemlist")));
 	if(NULL == model) {
 		/* set up a store of these attributes: 
-			- item title
 			- item label
+			- feed pointer
 			- item state (read/unread)		
 			- pointer to item data
 			- date time_t value
-			- the type of the feed the item belongs to
 			- feed icon
 		 */
 		itemstore = gtk_tree_store_new(IS_LEN,
 		                               G_TYPE_INT,
-		                               G_TYPE_STRING,
 		                               G_TYPE_STRING, 
 		                               G_TYPE_STRING,
+					       G_TYPE_POINTER,
 		                               GDK_TYPE_PIXBUF,
-		                               G_TYPE_POINTER, 
-		                               G_TYPE_INT,
+		                               G_TYPE_ULONG,
 		                               GDK_TYPE_PIXBUF);
 		gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(itemstore), IS_TIME, timeCompFunc, NULL, NULL);
 		g_signal_connect(G_OBJECT(itemstore), "sort-column-changed", G_CALLBACK(itemlist_sort_column_changed_cb), NULL);
@@ -100,6 +98,19 @@ GtkTreeStore * ui_itemlist_get_tree_store(void) {
 	return itemstore;
 }
 
+itemPtr ui_itemlist_get_item_from_iter(GtkTreeIter *iter) {
+	GtkTreeStore	*itemstore;
+	feedPtr		fp;
+	itemPtr		ip;
+	gulong		nr;
+	
+	itemstore = ui_itemlist_get_tree_store();
+	gtk_tree_model_get(GTK_TREE_MODEL(itemstore), iter, IS_FEED, &fp, IS_NR, &nr, -1);
+	ip = feed_lookup_item(fp, nr);
+	g_assert(ip != NULL);
+	return ip;
+}
+
 gchar * ui_itemlist_format_date(time_t t) {
 	gchar		*tmp;
 	gchar		*timestr;
@@ -147,14 +158,18 @@ void ui_itemlist_reset_date_format(void) {
 	date_format = NULL;
 }
 
-/* don't forget to remove the iterhash entry after calling this method! */
 void ui_itemlist_remove_item(itemPtr ip) {
-	GtkTreeStore	*itemstore = ui_itemlist_get_tree_store();
+	GtkTreeStore	*itemstore;
 	GtkTreeIter	*iter;
 
 	g_assert(NULL != ip);
-	if(NULL != (iter = g_hash_table_lookup(iterhash, (gpointer)ip)))
+	if(NULL != (iter = g_hash_table_lookup(iterhash, (gpointer)ip))) {
+		itemstore = ui_itemlist_get_tree_store();
 		gtk_tree_store_remove(itemstore, iter);
+		g_hash_table_remove(iterhash, (gpointer)ip);
+	} else {
+		/*g_warning("item to be removed not found in tree iter lookup hash!");*/
+	}
 }
 
 /* cleans up the item list, sets up the iter hash when called for the first time */
@@ -179,7 +194,7 @@ void ui_itemlist_clear(void) {
 		g_hash_table_destroy(iterhash);
 		gtk_tree_store_clear(itemstore);
 	}		
-	iterhash = g_hash_table_new(g_direct_hash, g_direct_equal);
+	iterhash = g_hash_table_new_full(g_direct_hash, g_direct_equal, NULL, g_free);
 }
 
 void ui_itemlist_update_item(itemPtr ip) {
@@ -188,7 +203,7 @@ void ui_itemlist_update_item(itemPtr ip) {
 	gchar		*title, *label, *time_str, *esc_title, *esc_time_str, *tmp;
 	GdkPixbuf	*icon = NULL, *favicon;
 
-	/* favicon for vfolders */
+	/* favicon for feed icon column (visible in folders/vfolders/searches) */
 	if(NULL != ip->sourceFeed)
 		favicon = ip->sourceFeed->icon;
 	else
@@ -269,7 +284,7 @@ void ui_itemlist_init(GtkWidget *itemlist) {
 	g_assert(mainwindow != NULL);
 	g_assert(itemlist != NULL);
 
-	iterhash = g_hash_table_new(g_direct_hash, g_direct_equal);
+	iterhash = g_hash_table_new_full(g_direct_hash, g_direct_equal, NULL, g_free);
 
 	itemstore = ui_itemlist_get_tree_store();
 
@@ -296,7 +311,7 @@ void ui_itemlist_init(GtkWidget *itemlist) {
 	renderer = gtk_cell_renderer_text_new();	
 	column = gtk_tree_view_column_new_with_attributes(_("Headline"), renderer, "markup", IS_LABEL, NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(itemlist), column);
-	gtk_tree_view_column_set_sort_column_id(column, IS_TITLE);
+	gtk_tree_view_column_set_sort_column_id(column, IS_LABEL);
 
 	g_object_set(column, "resizable", TRUE, NULL);
 	
@@ -369,15 +384,17 @@ void ui_itemlist_display(void) {
 				
 			valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(itemstore), &iter);
 			while(valid) {	
-				gtk_tree_model_get(GTK_TREE_MODEL(itemstore), &iter, IS_PTR, &ip, -1);
+				ip = ui_itemlist_get_item_from_iter(&iter);
 
 				if(item_get_read_status(ip)) 
 					addToHTMLBuffer(&buffer, UNSHADED_START);
 				else
 					addToHTMLBuffer(&buffer, SHADED_START);
-
-				addToHTMLBuffer(&buffer, item_render(ip));
-
+				
+				tmp = item_render(ip);
+				addToHTMLBuffer(&buffer, tmp);
+				g_free(tmp);
+				
 				if(item_get_read_status(ip))
 					addToHTMLBuffer(&buffer, UNSHADED_END);
 				else {
@@ -444,10 +461,9 @@ void ui_itemlist_add_item(itemPtr ip, gboolean merge) {
 			gtk_tree_store_prepend(itemstore, iter, NULL);
 			g_hash_table_insert(iterhash, (gpointer)ip, (gpointer)iter);
 		}	
-
 		gtk_tree_store_set(itemstore, iter,
-		                	      IS_TITLE, item_get_title(ip),
-		                	      IS_PTR, ip,
+		                	      IS_NR, ip->nr,
+					      IS_FEED, ip->fp,
 		                	      IS_TIME, item_get_time(ip),
 		                	      -1);
 		ui_itemlist_update_item(ip);
@@ -465,15 +481,14 @@ void ui_itemlist_enable_favicon_column(gboolean enabled) {
 static itemPtr ui_itemlist_get_selected() {
 	GtkTreeIter		iter;
 	GtkTreeModel		*model;
-	itemPtr			item = NULL;
 	GtkTreeSelection	*selection;
 
-	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(lookup_widget(mainwindow, "Itemlist")));
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(lookup_widget(mainwindow, "Itemlist")));	
 	
 	if(gtk_tree_selection_get_selected(selection, &model, &iter))
-		gtk_tree_model_get(model, &iter, IS_PTR, &item, -1);
-
-	return item;
+		return ui_itemlist_get_item_from_iter(&iter);
+		
+	return NULL;
 }
 
 void on_popup_launchitem_selected(void) {
@@ -577,8 +592,7 @@ static gboolean ui_itemlist_find_unread_item(void) {
 		
 	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(itemstore), &iter);
 	while(valid) {
-		gtk_tree_model_get(GTK_TREE_MODEL(itemstore), &iter, IS_PTR, &ip, -1);
-		g_assert(ip != NULL);
+		ip = ui_itemlist_get_item_from_iter(&iter);
 		if(FALSE == item_get_read_status(ip)) {
 			if(!ui_itemlist_get_two_pane_mode()) {
 				ui_itemlist_select(iter);
@@ -644,11 +658,10 @@ gboolean on_itemlist_button_press_event(GtkWidget *widget, GdkEventButton *event
 		return FALSE;
 
 	gtk_tree_model_get_iter(GTK_TREE_MODEL(ui_itemlist_get_tree_store()), &iter, path);
-	gtk_tree_model_get(GTK_TREE_MODEL(itemstore), &iter,
-					    IS_PTR, &ip,
-					    -1);
 	gtk_tree_path_free(path);
-	g_assert(NULL != ip);
+	
+	ip = ui_itemlist_get_item_from_iter(&iter);
+
 	eb = (GdkEventButton*)event; 
 	switch(eb->button) {
 		case 2:
